@@ -21,10 +21,14 @@ class DelegatedUserManager {
     }
     
     /**
-     * Get MySQL database connection
+     * Get MySQL database connection with whp database selected
      */
     private function getConnection() {
-        return $this->mysql_mgmt->getMySQLConnection();
+        $db = $this->mysql_mgmt->getMySQLConnection();
+        if ($db) {
+            $db->exec("USE whp");
+        }
+        return $db;
     }
     
     /**
@@ -447,8 +451,15 @@ class DelegatedUserManager {
      * Check if username exists (system or delegated)
      */
     private function usernameExists($username) {
-        // Check system users (basic check - would need more sophisticated check in production)
-        $system_user_exists = posix_getpwnam($username) !== false;
+        // Check system users (basic check using /etc/passwd if available)
+        $system_user_exists = false;
+        if (function_exists('posix_getpwnam')) {
+            $system_user_exists = posix_getpwnam($username) !== false;
+        } elseif (file_exists('/etc/passwd')) {
+            // Fallback method: check /etc/passwd file
+            $passwd_content = file_get_contents('/etc/passwd');
+            $system_user_exists = strpos($passwd_content, $username . ':') !== false;
+        }
         
         if ($system_user_exists) {
             return true;
