@@ -139,21 +139,30 @@ if ($is_root) {
 .permission-checkbox-group {
     display: grid;
     grid-template-columns: repeat(auto-fit, minmax(200px, 1fr));
-    gap: 10px;
-    margin: 10px 0;
+    gap: 15px;
+    margin: 15px 0;
 }
 
 .permission-checkbox {
     display: flex;
     align-items: center;
-    padding: 8px;
+    padding: 12px;
     border: 1px solid #dee2e6;
-    border-radius: 4px;
-    background: #f8f9fa;
+    border-radius: 6px;
+    background: #ffffff;
+    box-shadow: 0 1px 3px rgba(0,0,0,0.1);
 }
 
 .permission-checkbox input[type="checkbox"] {
-    margin-right: 8px;
+    margin-right: 10px;
+    transform: scale(1.1);
+}
+
+.permission-checkbox label {
+    color: #212529;
+    font-weight: 500;
+    margin-bottom: 0;
+    cursor: pointer;
 }
 
 .delegated-user-card {
@@ -299,36 +308,36 @@ if ($is_root) {
                                 <label class="form-label">Permissions</label>
                                 <div class="permission-checkbox-group">
                                     <div class="permission-checkbox">
-                                        <input type="checkbox" id="can_manage_domains" name="can_manage_domains">
-                                        <label for="can_manage_domains">Manage Domains</label>
+                                        <input type="checkbox" id="can_manage_domains" name="can_manage_domains" class="form-check-input">
+                                        <label for="can_manage_domains" class="form-check-label">Manage Domains</label>
                                     </div>
                                     <div class="permission-checkbox">
-                                        <input type="checkbox" id="can_manage_sites" name="can_manage_sites">
-                                        <label for="can_manage_sites">Manage Sites</label>
+                                        <input type="checkbox" id="can_manage_sites" name="can_manage_sites" class="form-check-input">
+                                        <label for="can_manage_sites" class="form-check-label">Manage Sites</label>
                                     </div>
                                     <div class="permission-checkbox">
-                                        <input type="checkbox" id="can_manage_databases" name="can_manage_databases">
-                                        <label for="can_manage_databases">Manage Databases</label>
+                                        <input type="checkbox" id="can_manage_databases" name="can_manage_databases" class="form-check-input">
+                                        <label for="can_manage_databases" class="form-check-label">Manage Databases</label>
                                     </div>
                                     <div class="permission-checkbox">
-                                        <input type="checkbox" id="can_manage_email" name="can_manage_email">
-                                        <label for="can_manage_email">Manage Email</label>
+                                        <input type="checkbox" id="can_manage_email" name="can_manage_email" class="form-check-input">
+                                        <label for="can_manage_email" class="form-check-label">Manage Email</label>
                                     </div>
                                     <div class="permission-checkbox">
-                                        <input type="checkbox" id="can_manage_files" name="can_manage_files">
-                                        <label for="can_manage_files">Manage Files</label>
+                                        <input type="checkbox" id="can_manage_files" name="can_manage_files" class="form-check-input">
+                                        <label for="can_manage_files" class="form-check-label">Manage Files</label>
                                     </div>
                                     <div class="permission-checkbox">
-                                        <input type="checkbox" id="can_manage_backups" name="can_manage_backups">
-                                        <label for="can_manage_backups">Manage Backups</label>
+                                        <input type="checkbox" id="can_manage_backups" name="can_manage_backups" class="form-check-input">
+                                        <label for="can_manage_backups" class="form-check-label">Manage Backups</label>
                                     </div>
                                     <div class="permission-checkbox">
-                                        <input type="checkbox" id="can_view_terminal" name="can_view_terminal">
-                                        <label for="can_view_terminal">Access Terminal</label>
+                                        <input type="checkbox" id="can_view_terminal" name="can_view_terminal" class="form-check-input">
+                                        <label for="can_view_terminal" class="form-check-label">Access Terminal</label>
                                     </div>
                                     <div class="permission-checkbox">
-                                        <input type="checkbox" id="can_manage_wordpress" name="can_manage_wordpress">
-                                        <label for="can_manage_wordpress">Manage WordPress</label>
+                                        <input type="checkbox" id="can_manage_wordpress" name="can_manage_wordpress" class="form-check-input">
+                                        <label for="can_manage_wordpress" class="form-check-label">Manage WordPress</label>
                                     </div>
                                 </div>
                             </div>
@@ -508,36 +517,36 @@ if ($is_root) {
                                 <label class="form-label">Permissions</label>
                                 <div class="permission-checkbox-group">
                                     <div class="permission-checkbox">
-                                        <input type="checkbox" id="edit_can_manage_domains" name="can_manage_domains">
-                                        <label for="edit_can_manage_domains">Manage Domains</label>
+                                        <input type="checkbox" id="edit_can_manage_domains" name="can_manage_domains" class="form-check-input">
+                                        <label for="edit_can_manage_domains" class="form-check-label">Manage Domains</label>
                                     </div>
                                     <div class="permission-checkbox">
-                                        <input type="checkbox" id="edit_can_manage_sites" name="can_manage_sites">
-                                        <label for="edit_can_manage_sites">Manage Sites</label>
+                                        <input type="checkbox" id="edit_can_manage_sites" name="can_manage_sites" class="form-check-input">
+                                        <label for="edit_can_manage_sites" class="form-check-label">Manage Sites</label>
                                     </div>
                                     <div class="permission-checkbox">
-                                        <input type="checkbox" id="edit_can_manage_databases" name="can_manage_databases">
-                                        <label for="edit_can_manage_databases">Manage Databases</label>
+                                        <input type="checkbox" id="edit_can_manage_databases" name="can_manage_databases" class="form-check-input">
+                                        <label for="edit_can_manage_databases" class="form-check-label">Manage Databases</label>
                                     </div>
                                     <div class="permission-checkbox">
-                                        <input type="checkbox" id="edit_can_manage_email" name="can_manage_email">
-                                        <label for="edit_can_manage_email">Manage Email</label>
+                                        <input type="checkbox" id="edit_can_manage_email" name="can_manage_email" class="form-check-input">
+                                        <label for="edit_can_manage_email" class="form-check-label">Manage Email</label>
                                     </div>
                                     <div class="permission-checkbox">
-                                        <input type="checkbox" id="edit_can_manage_files" name="can_manage_files">
-                                        <label for="edit_can_manage_files">Manage Files</label>
+                                        <input type="checkbox" id="edit_can_manage_files" name="can_manage_files" class="form-check-input">
+                                        <label for="edit_can_manage_files" class="form-check-label">Manage Files</label>
                                     </div>
                                     <div class="permission-checkbox">
-                                        <input type="checkbox" id="edit_can_manage_backups" name="can_manage_backups">
-                                        <label for="edit_can_manage_backups">Manage Backups</label>
+                                        <input type="checkbox" id="edit_can_manage_backups" name="can_manage_backups" class="form-check-input">
+                                        <label for="edit_can_manage_backups" class="form-check-label">Manage Backups</label>
                                     </div>
                                     <div class="permission-checkbox">
-                                        <input type="checkbox" id="edit_can_view_terminal" name="can_view_terminal">
-                                        <label for="edit_can_view_terminal">Access Terminal</label>
+                                        <input type="checkbox" id="edit_can_view_terminal" name="can_view_terminal" class="form-check-input">
+                                        <label for="edit_can_view_terminal" class="form-check-label">Access Terminal</label>
                                     </div>
                                     <div class="permission-checkbox">
-                                        <input type="checkbox" id="edit_can_manage_wordpress" name="can_manage_wordpress">
-                                        <label for="edit_can_manage_wordpress">Manage WordPress</label>
+                                        <input type="checkbox" id="edit_can_manage_wordpress" name="can_manage_wordpress" class="form-check-input">
+                                        <label for="edit_can_manage_wordpress" class="form-check-label">Manage WordPress</label>
                                     </div>
                                 </div>
                             </div>
